==> openstack-swift-1.9.2-sources.jar: org/jclouds/openstack/swift/v1/blobstore/config/SignUsingTemporaryUrls.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.openstack.swift.v1.blobstore.config;

import javax.inject.Inject;

import org.jclouds.blobstore.BlobRequestSigner;
import org.jclouds.date.TimeStamp;
import org.jclouds.openstack.swift.v1.blobstore.RegionScopedTemporaryUrlBlobSigner;

import com.google.common.base.Function;
import com.google.common.collect.ForwardingObject;
import com.google.inject.AbstractModule;
import com.google.inject.Provides;
import com.google.inject.assistedinject.FactoryModuleBuilder;

public class SignUsingTemporaryUrls extends AbstractModule {

   @Override
   protected void configure() {
      install(new FactoryModuleBuilder().build(Factory.class));
   }

   interface Factory {
      RegionScopedTemporaryUrlBlobSigner create(String in);
   }

   @Provides
   Function<String, BlobRequestSigner> blobRequestSigner(FactoryFunction in) {
      return in;
   }

   static class FactoryFunction extends ForwardingObject implements Function<String, BlobRequestSigner> {
      @Inject
      Factory delegate;

      @Override
      protected Factory delegate() {
         return delegate;
      }

      @Override
      public BlobRequestSigner apply(String in) {
         return delegate.create(in);
      }
   }

   @Provides
   @TimeStamp
   protected Long unixEpochTimestamp() {
      return System.currentTimeMillis() / 1000;
   }
}

==> openstack-swift-2.7.0-sources.jar: org/jclouds/openstack/swift/v1/blobstore/config/SignUsingTemporaryUrls.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.jclouds.openstack.swift.v1.blobstore.config;

import jakarta.inject.Inject;

import org.jclouds.blobstore.BlobRequestSigner;
import org.jclouds.date.TimeStamp;
import org.jclouds.openstack.swift.v1.blobstore.RegionScopedTemporaryUrlBlobSigner;

import com.google.common.base.Function;
import com.google.common.collect.ForwardingObject;
import com.google.inject.AbstractModule;
import com.google.inject.Provides;
import com.google.inject.assistedinject.FactoryModuleBuilder;

public class SignUsingTemporaryUrls extends AbstractModule {

   @Override
   protected void configure() {
      install(new FactoryModuleBuilder().build(Factory.class));
   }

   interface Factory {
      RegionScopedTemporaryUrlBlobSigner create(String in);
   }

   @Provides
   Function<String, BlobRequestSigner> blobRequestSigner(FactoryFunction in) {
      return in;
   }

   static class FactoryFunction extends ForwardingObject implements Function<String, BlobRequestSigner> {
      @Inject
      Factory delegate;

      @Override
      protected Factory delegate() {
         return delegate;
      }

      @Override
      public BlobRequestSigner apply(String in) {
         return delegate.create(in);
      }
   }

   @Provides
   @TimeStamp
   protected Long unixEpochTimestamp() {
      return System.currentTimeMillis() / 1000;
   }
}
